/*
    Copyright (C) 2004, Wolfgang Hottgenroth

    This file is part of smmapdfw.

    smmapdfw is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.  

    smmapdfw is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details. 

    You should have received a copy of the GNU General Public License
    along with smmapdfw. If not, write to the Free Software Foundation, 59
    Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#include <assert.h>
#include <syslog.h>

#include "config.h"

#define _STATS_C_
#include "stats.h"

#include "count.h"


#if ENABLE_STATS==1
count_t statCounter[STAT_CNT_MAXNUM];
#endif

void initStatCounter() {
#if ENABLE_STATS==1
  int i;

  for (i=0; i<STAT_CNT_MAXNUM; i++) {
    count_init(&statCounter[i]);
  }
#endif
}

unsigned int getStatCounter(int cnt_idx) {
#if ENABLE_STATS==1
  assert((cnt_idx >= 0) && (cnt_idx < STAT_CNT_MAXNUM));
  return count_get(&statCounter[cnt_idx]);
#else
  return 0;
#endif
}

void incStatCounter(int cnt_idx) {
#if ENABLE_STATS==1
  assert((cnt_idx >= 0) && (cnt_idx < STAT_CNT_MAXNUM));
  count_inc(&statCounter[cnt_idx]);
#endif
}

void decStatCounter(int cnt_idx) {
#if ENABLE_STATS==1
  assert((cnt_idx >= 0) && (cnt_idx < STAT_CNT_MAXNUM));
  count_dec(&statCounter[cnt_idx]);
#endif
}

void outputStats(int stdout_nice, int syslog_nice) {
#if ENABLE_STATS==1
  char buf[1024];
  char buf2[64];
  int i, v;
  
  *buf = '\0';
  *buf2 = '\0';

  strcat(buf, "Stats: ");

  if (2 == stdout_nice)
    printf("---------------------------------------------------------\n");

  for (i=1; i<STAT_CNT_MAXNUM; i++) {
    v = getStatCounter(i);
    if (2 == stdout_nice)
      printf("%44s = %5d\n", stat_cnt_names[i], v);
    if (2 == syslog_nice)
      syslog(LOG_DEBUG, "%44s = %5d\n", stat_cnt_names[i], v);
    if ((1 == stdout_nice) || (1 == syslog_nice)) {
      sprintf(buf2, "%d ", v);
      strcat(buf, buf2);
    }
  }

  if (stdout_nice)
  printf("\n");

  if (1 == stdout_nice)
    printf("%s\n\n", buf);
  if (1 == syslog_nice)
    syslog(LOG_DEBUG, buf);
#endif
}

    
